[![License](https://img.shields.io/badge/license-GPL-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html)
[![pypiversion](https://img.shields.io/pypi/v/xemc3.svg)](https://pypi.python.org/pypi/xemc3)
[![py3comp](https://img.shields.io/badge/py3-compatible-brightgreen.svg)](https://img.shields.io/badge/py3-compatible-brightgreen.svg)
[![DOI](https://zenodo.org/badge/doi/10.5281/zenodo.5562265.svg)](https://doi.org/10.5281/zenodo.5562265)

# xemc3

A library for working with EMC3 simulations using the xarray framework.

## Examples
Examples can be found under [docs/examples](docs/examples) and you can try them [online on binder](https://mybinder.org/v2/gh/dschwoerer/xemc3/next?filepath=docs%2Fexamples)

## Documentation
The documentation can be found on [read the docs](https://xemc3.rtfd.io)

## Installation
```bash
pip install xemc3
```

## Citation
If you use xemc3, please cite it using [DOI: 10.5281/zenodo.5562265](https://doi.org/10.5281/zenodo.5562265)
